@@ -33,6 +33,7 @@
 #include "parser/backtraceparser.h"
 #include "productmapping.h"
 #include "sentryconnection.h"
+#include "sentryscope.h"
 #include "settings.h"
 #include "systeminformation.h"
 
@@ -377,6 +378,7 @@ void ReportInterface::prepareEventPayload()
     bool hadIncompatibleQt = false;
 
     constexpr auto TAGS_KEY = "tags"_L1;
+    constexpr auto CONTEXTS_KEY = "contexts"_L1;
 
     {
         auto tags = hash.take(TAGS_KEY).toHash();
@@ -431,13 +433,43 @@ void ReportInterface::prepareEventPayload()
     }
 
     {
-        constexpr auto CONTEXTS_KEY = "contexts"_L1;
         auto context = hash.take(CONTEXTS_KEY).toHash();
-        context.insert(u"gpu"_s,
-                       QVariantHash{
-                           {u"name"_s, DrKonqi::instance()->m_glRenderer}, //
-                           {u"version"_s, QGuiApplication::platformName()}, // NOTE: drkonqi gets invoked with the same platform as the crashed app
-                       });
+        if (!DrKonqi::crashedApplication()->m_gpu.isEmpty()) {
+            QVariantHash data = DrKonqi::crashedApplication()->m_gpu;
+
+            auto ulonglongify = [&data](const QString &key) {
+                if (!data.contains(key)) {
+                    return;
+                }
+                const auto &value = data[key];
+                if (value.toString().isEmpty()) {
+                    return;
+                }
+                data[key] = value.toULongLong();
+            };
+
+            auto boolify = [&data](const QString &key) {
+                if (!data.contains(key)) {
+                    return;
+                }
+                const auto &value = data[key];
+                if (value.toString().isEmpty()) {
+                    return;
+                }
+                data[key] = value.toBool();
+            };
+
+            // We need to do some type coercion here since Sentry will get angry over incorrect incoming types
+            ulonglongify(u"max_texture_size"_s);
+            ulonglongify(u"memory_size"_s);
+            boolify(u"multi_threaded_rendering"_s);
+            boolify(u"supports_compute_shaders"_s);
+            boolify(u"supports_draw_call_instancing"_s);
+            boolify(u"supports_geometry_shaders"_s);
+            boolify(u"supports_ray_tracing"_s);
+
+            context.insert(u"gpu"_s, data);
+        }
         hash.insert(CONTEXTS_KEY, context);
     }
 
@@ -522,6 +554,18 @@ void ReportInterface::prepareEventPayload()
     }
 
     if (receivedEmptyPayload) {
+        // DrKonqi also had a problem, so lets tie this broken report to our preamble through the global trace id.
+        auto context = hash.take(CONTEXTS_KEY).toHash();
+        context.insert(u"trace"_s,
+                       QJsonObject{
+                           {u"trace_id"_s, SentryScope::instance()->traceId}, //
+                           {u"span_id"_s, SentryScope::instance()->spanId},
+                           {u"op"_s, u"drkonqi.trace"_s},
+                           {u"type"_s, u"trace"_s},
+                       });
+        hash.insert(CONTEXTS_KEY, context);
+
+        // And mark it as broken
         hash.insert(u"message"_s, "Empty Sentry payload from GDB"_ba);
         hash.insert(u"level"_s, u"warning"_s);
     }
